==> haskell-unicode-show-0.1.1.1-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-show
version:              0.1.1.1
visibility:           public
id:                   unicode-show-0.1.1.1-AoJNtSQ8dss2I1rbusRMXP
key:                  unicode-show-0.1.1.1-AoJNtSQ8dss2I1rbusRMXP
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           igrep@n.email.ne.jp
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  44921f0dd5e26045f0fa8dd58f5c770b
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/unicode-show-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unicode-show-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unicode-show-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-show
hs-libraries:         HSunicode-show-0.1.1.1-AoJNtSQ8dss2I1rbusRMXP
depends:
    base-4.17.2.1 safe-0.3.21-BTgY19Ix98PEQ0IXGyRX6s
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-show-0.1.1.1-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-show
version:              0.1.1.1
visibility:           public
id:                   unicode-show-0.1.1.1-1aXYdmdpfnb6r1lSfhqru2
key:                  unicode-show-0.1.1.1-1aXYdmdpfnb6r1lSfhqru2
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           igrep@n.email.ne.jp
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  6c1a69e1ae28ec5b98ec44f19d647ec0
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/unicode-show-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unicode-show-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unicode-show-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-show
hs-libraries:         HSunicode-show-0.1.1.1-1aXYdmdpfnb6r1lSfhqru2
depends:
    base-4.17.2.1 safe-0.3.21-8UNW4gIoNRmKgGFufdPOla
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
